require "player"
require "enemies"
require "explosion"
require "powerups"
require "health"
require "buttons"
require "transition"
require "damage"

flux = require "flux"
local waiting = false
clicked = false

function love.load()
	gamestate = "Playing"
	gamestate = "Title"
	mute = false
	tType = nil
	pause = love.graphics.newImage("Pictures/Pause.png")
	playerPic = love.graphics.newImage("Pictures/Player.png")
	hitExplosion = love.audio.newSource("Audio/Explosion.wav")
	hurt = love.audio.newSource("Audio/Hurt.wav")
	ping = love.audio.newSource("Audio/Ping.wav")

	title = {}
	title.pic = love.graphics.newImage("Pictures/Title.png")
	title.x = 0
	title.y = 0

	background = {}
	background.pic = love.graphics.newImage("Pictures/Background.png")
	background.x = 0
	background.y = 800

	options = {}
	options.x = 0
	options.y = -800
	options.pic = love.graphics.newImage("Pictures/Options.png")

	gameOver = {}
	gameOver.x = 0
	gameOver.y = 0
	gameOver.pic = love.graphics.newImage("Pictures/GameOver.png")

	buttons.create("Play")
	buttons.create("Options")
	buttons.create("Volume")
	buttons.create("Mute")
	player.load()
	health.load()
end


function resetGame()
	if #enemies > 0  then
		table.remove(enemies,1)
	end
	if #powerups > 0 then
		table.remove(powerups,1)
	end
	if #damage > 0 then
		table.remove(damage,1)
	end
	if #explosion > 0 then
		table.remove(explosion,1)
	end
	if #powerups == 0 and #enemies == 0 and #damage == 0 and #explosion == 0 then
		wave = 1
		enemyCount = 0
		timer = 0
		sTimer = 0
		enemyLimit = 5
		player.health = 5
		player.score = 0
		effectTime = 50
		player.load()
		if tType == "GameOver" then
			gamestate = "Transitioning"
		else
			gamestate = "Playing"
		end
	end
end

function love.keypressed(key)
	if key == "escape" then
		if gamestate == "Paused" then
			gamestate = "Playing"
		elseif gamestate == "Playing" then
			gamestate = "Paused"
		elseif gamestate == "GameOver" then
			love.event.push ( "quit" )
		end
	end
	if key == "return" then
		if gamestate == "GameOver" then
			tType = "GameOver"
			gamestate = "Waiting"
		end
	end
	if key == "right" then
		player.shoot("right")
	end
	if key == "left" then
		player.shoot("left")
	end
	if key == "up" then
		player.shoot("up")
	end
	if key == "down" then
		player.shoot("down")
	end
end

function love.mousepressed(x,y,button)
	for i,v in ipairs(buttons) do
		if
		x > v.x and x < v.x + v.width
			and
		y > v.y and y < v.y + v.height
			and clicked == false
		then
			if gamestate == "Title" then
				if v.bType == "Play" then
					tType = "Play"
					gamestate = "Transitioning"
				end
			end
			if gamestate == "Paused" then
				if v.bType == "Volume" and v.a == 50 then
					love.audio.setVolume(v.level)
					love.audio.play(ping)
					v.a = 100
					for o,b in ipairs(buttons) do
						if b.bType == "Volume" and b.x < v.x then
							b.a = 100
						end
					end
				end
				if v.bType == "Volume" and v.a == 100 then
					love.audio.setVolume(v.level)
					love.audio.play(ping)
					v.a = 100
					for o,b in ipairs(buttons) do
						if b.bType == "Volume" and b.x > v.x then
							b.a = 50
						end
					end
				end
			end
		end
	end
end




function love.update(dt)
	if gamestate == "Playing" then
		updateEnemies(dt)
		updatePlayer(dt)
		updateExplosion(dt)
		updatePowerUps(dt)
		updateHealth(dt)
		updateDamage(dt)
	elseif gamestate == "Title" then
		updateButtons(dt)
	elseif gamestate == "Transitioning" then
		transition.update(dt)
	end

end




function love.draw()
	if gamestate == "Playing" or gamestate == "Paused" then
		love.graphics.draw(background.pic,background.x,background.y)
		r, g, b, a = love.graphics.getColor( )
		drawPowerUps()
		drawDamage()
		love.graphics.setColor(255,0,0)
		drawHealth()
		drawEnemies()
		drawPlayer()
		drawExplosion()
	elseif gamestate == "Title" then
		love.graphics.draw(title.pic,title.x,title.y)
		r, g, b, a = love.graphics.getColor( )
		love.graphics.setColor(0,0,0,60)
		drawButtons()
		love.graphics.setColor(r,g,b)
	elseif gamestate == "Waiting" then
			resetGame()
	end
	if gamestate == "Paused" then
		love.graphics.draw(pause,0,0)
		drawButtons()
	end
	if gamestate == "GameOver" then
		love.graphics.draw(gameOver.pic,gameOver.x,gameOver.y)
	end
	if gamestate == "Transitioning" then
		transition.draw()
	end
	if gamestate == "Options" then
		love.graphics.draw(options.pic,options.x,options.y)
	end
	love.graphics.print(tostring(love.timer.getFPS( )).." FPS", 10, 10)
end