player = {}


function player.load()
	player.width = 20
	player.height = 20
	player.x = love.graphics.getWidth()/2 - player.width/2
	player.y = (love.graphics.getHeight()/2) + player.height/2
	player.xVel = 0
	player.yVel = 0
	player.speed = 50
	player.health = 117
	player.score = 0
	player.friction = .85
	player.shots = {}
end





function player.shoot(dir)
	if dir == "right" then
		local shot = {}
		shot.debounce = false
		shot.width = 5
		shot.height = 5
		shot.x = player.x + player.width
		shot.y = player.y + player.height/2 - shot.height/2
		shot.dir = dir
		shot.speed = 1000


		table.insert(player.shots,shot)
	end
	if dir == "up" then
		local shot = {}
		shot.width = 5
		shot.height = 5
		shot.x = player.x + player.width/2 - shot.width/2
		shot.y = player.y + player.height
		shot.dir = dir
		shot.speed = 1000


		table.insert(player.shots,shot)
	end
	if dir == "down" then
		local shot = {}
		shot.width = 5
		shot.height = 5
		shot.x = player.x + player.width/2 - shot.width/2
		shot.y = player.y + player.width
		shot.dir = dir
		shot.speed = 1000


		table.insert(player.shots,shot)
	end
	if dir == "left" then
		local shot = {}
		shot.width = 5
		shot.height = 5
		shot.x = player.x
		shot.y = player.y + player.height/2 - shot.height/2
		shot.dir = dir
		shot.speed = 1000


		table.insert(player.shots,shot)
	end
end



function updateShots(dt)
	for i,v in ipairs(player.shots) do
		if v.dir == "right" then
			v.x = v.x + v.speed * dt
		end
		if v.dir == "left" then
			v.x = v.x - v.speed * dt
		end
		if v.dir == "up" then
			v.y = v.y - v.speed * dt
		end
		if v.dir == "down" then
			v.y = v.y + v.speed * dt
		end
		if v.x + v.width < 0 or 
			v.x > love.graphics.getWidth() or
			v.y + v.height < 0 or
			v.y > love.graphics.getHeight() 
		then
			table.remove(player.shots,i)
		end
	end
end

function drawShots()
	for i,v in ipairs(player.shots) do
		love.graphics.setColor(255,0,0)
		love.graphics.rectangle("fill", v.x, v.y, v.width, v.height)
	end
end

function shotCollisions()
	for i,v in ipairs(player.shots) do
		for o,b in ipairs(enemies) do
			if v.y < b.y + b.height and v.y + v.height > b.y and v.x < b.x + b.width and v.x + v.width > b.x
			or
			v.x < b.x + b.width and v.x + v.width > b.x and v.y < b.y + b.height and v.y + v.height > b.y
			then
				explosion.spawn(b.x,b.y)
				b.health = b.health - 1
				player.score = player.score + b.hitPoints
				if b.health == 0 then
					table.remove(enemies,o)
				end
				b.xVel = -b.xVel
				b.yVel = -b.yVel
				love.audio.play(hitExplosion)
				table.remove(player.shots,i)
			end
		end
	end
end


function player.boundary()
	if player.x < 0 then
		player.xVel = player.xVel * -1
		player.x = 0
	end
	if player.x +player.width > love.graphics.getWidth() then
		player.xVel = player.xVel * -1
		player.x = love.graphics.getWidth() - player.width
	end
	if player.y < 0 then
		player.yVel = player.yVel * -1
		player.y = 0
	end
	if player.y +player.height > love.graphics.getHeight() then
		player.yVel = player.yVel * -1
		player.y = love.graphics.getHeight() - player.height
	end
end


function player.update(dt)
	player.xVel = player.xVel * player.friction
	player.yVel = player.yVel * player.friction
	player.x = player.x + player.xVel
	player.y = player.y + player.yVel
	if love.keyboard.isDown("w") then
		player.yVel = player.yVel - player.speed * dt
	end
	if love.keyboard.isDown("s") then
		player.yVel = player.yVel + player.speed * dt
	end
	if love.keyboard.isDown("a") then
		player.xVel = player.xVel - player.speed * dt
	end
	if love.keyboard.isDown("d") then
		player.xVel = player.xVel + player.speed * dt
	end
end


function player.draw()
	love.graphics.setColor(255,255,255)
	love.graphics.draw(playerPic, player.x, player.y)
	love.graphics.setColor(255,255,255)
	love.graphics.print(player.score,760,10)
end





function updatePlayer(dt)
	shotCollisions()
	updateShots(dt)
	player.update(dt)
	player.boundary()
end


function drawPlayer()
	love.graphics.setColor(255,0,0)
	drawShots()
	player.draw()
end

